==> hubzero-python_1.2.13.orig.tar.gz: hubzero-python-1.2.13/hubzero/utilities/misc.py <==
# @package      hubzero-python
# @file         misc.py
# @author       David Benham <dbenham@purdue.edu>
# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#

import os
import subprocess
import traceback

JOOMLA_25 = False

def isDebian():
	return os.path.exists("/etc/debian_version")
	
def isRHEL():
	return os.path.exists("/etc/redhat-release")

def exShellCommand(argArray, processInput=''):
	""" Wrapper to run and return output of a shell command """
	
	try:
		proc = subprocess.Popen(argArray,
			                    shell=False,
			                    stdin=subprocess.PIPE,
			                    stdout=subprocess.PIPE,
			                    stderr=subprocess.PIPE)
	
		procStdOut, procStdErr = proc.communicate(processInput)
		rc = proc.returncode

	except Exception, ex:	
		raise Exception('exShellCommand error ' + str(argArray) + ' ' + str(ex) + "\n" + traceback.format_exc())

	return rc, procStdOut, procStdErr

==> hubzero-python_1.2.14.orig.tar.gz: hubzero-python-1.2.14/hubzero/utilities/misc.py <==
# @package      hubzero-python
# @file         misc.py
# @author       David Benham <dbenham@purdue.edu>
# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#

import os
import subprocess
import traceback
import platform

JOOMLA_25 = False

def isDebian():
	distname, version = platform.linux_distribution(full_distribution_name=False)
	return distname == 'debian'
	
def isRHEL():
	distname, version = platform.linux_distribution(full_distribution_name=False)
	return distname == 'redhat'


def exShellCommand(argArray, processInput=''):
	""" Wrapper to run and return output of a shell command """
	
	try:
		proc = subprocess.Popen(argArray,
			                    shell=False,
			                    stdin=subprocess.PIPE,
			                    stdout=subprocess.PIPE,
			                    stderr=subprocess.PIPE)
	
		procStdOut, procStdErr = proc.communicate(processInput)
		rc = proc.returncode

	except Exception, ex:	
		raise Exception('exShellCommand error ' + str(argArray) + ' ' + str(ex) + "\n" + traceback.format_exc())

	return rc, procStdOut, procStdErr
